@@ -6,10 +6,10 @@ import torch
 from spider.utils.collision.SAT import SAT_check
 from spider.elements.Box import obb2vertices
 from spider.elements.trajectory import FrenetTrajectory
-from spider.RL.reward.BasicReward import BasicReward
+from spider.RL.reward.BaseReward import BaseReward
 
 
-class FstateControlReward(BasicReward):
+class FstateControlReward(BaseReward):
     def __init__(self, config: dict):
         super(FstateControlReward, self).__init__()
         # self.trajectory_candidates: Sequence[FrenetTrajectory] = []
