@@ -6,10 +6,10 @@ import torch
 from spider.utils.collision.SAT import SAT_check
 from spider.elements.Box import obb2vertices
 from spider.elements.trajectory import FrenetTrajectory
-from spider.RL.reward.BasicReward import BasicReward
+from spider.RL.reward.BaseReward import BaseReward
 
 
-class FstateTrajectoryReward(BasicReward):
+class FstateTrajectoryReward(BaseReward):
     def __init__(self, config: dict):
         super(FstateTrajectoryReward, self).__init__()
         self.trajectory_candidates: Sequence[FrenetTrajectory] = []
@@ -35,7 +35,7 @@ class FstateTrajectoryReward(BasicReward):
     def set_trajectory_candidates(self, trajectory_candidates: Sequence[FrenetTrajectory]) -> None:
         self.trajectory_candidates = trajectory_candidates
 
-    def evaluate(self, state, action, next_state) -> Tuple[float, bool]:
+    def evaluate(self, state=None, action=None, next_state=None) -> Tuple[float, bool]:
         if state is None or action is None or next_state is None:
             return 0.0, False
 
