@@ -4,7 +4,7 @@ import numpy as np
 import torch
 import tqdm
 
-from spider.planner_zoo.BasicPlanner import BasicPlanner
+from spider.planner_zoo.BasePlanner import BasePlanner
 
 from spider.elements.map import RoutedLocalMap
 from spider.elements.trajectory import FrenetTrajectory
@@ -54,7 +54,7 @@ while True:
 '''
 
 
-class MFRLPlanner(BasicPlanner):
+class MFRLPlanner(BasePlanner):
     def __init__(self, config=None, device=None):
         super(MFRLPlanner, self).__init__()
 
@@ -180,6 +180,9 @@ class MFRLPlanner(BasicPlanner):
         optimal_trajectory = candidate_trajectories[action]
         return optimal_trajectory
 
+    def load_model(self, model_filename):
+        self.agent.load_model(model_filename)
+
     def save_experience_buffer(self):
         pass
 
@@ -187,7 +190,7 @@ class MFRLPlanner(BasicPlanner):
         self.agent.learn()
 
     def save_model(self, filename:str):
-        self.agent.save_q_network_model(filename)
+        self.agent.save_model(filename)
 
     def plan(self, ego_veh_state:VehicleState, obstacles:TrackingBoxList, local_map:RoutedLocalMap=None, train=False) \
             -> Union[FrenetTrajectory, None]:
@@ -233,12 +236,14 @@ class MFRLPlanner(BasicPlanner):
         long_samples = self.longitudinal_sampler.sample((fstate_start.s, fstate_start.s_dot, fstate_start.s_2dot))
         lat_samples = self.lateral_sampler.sample((fstate_start.l, fstate_start.l_prime, fstate_start.l_2prime))
         candidate_trajectories = self.trajectory_combiner.combine(lat_samples, long_samples)
-        self.reward_function.set_trajectory_candidates(candidate_trajectories)
+        self.reward_function.set_trajectory_candidates(candidate_trajectories) # reward function里的碰撞是frenet坐标下的
 
         # 轨迹坐标转换，把每个轨迹点转到笛卡尔坐标
         # todo:qzl: 其实candidates_trajectories不用算出来的，会耗损计算资源，能不能储存Generator形式的？调用的时候再进行计算
-        candidate_trajectories = [self.coordinate_transformer.frenet2cart4traj(t, order=2) for t in candidate_trajectories]
+        # candidate_trajectories = [self.coordinate_transformer.frenet2cart4traj(t, order=2) for t in candidate_trajectories]
         optimal_trajectory = self.decode_action(self.action,candidate_trajectories)  # 动作解码器
+        if not (optimal_trajectory is None):
+            optimal_trajectory = self.coordinate_transformer.frenet2cart4traj(optimal_trajectory, order=2)
 
         self._candidate_trajectories = candidate_trajectories
 
@@ -283,7 +288,7 @@ if __name__ == '__main__':
         rl_planner.configure({"closed_loop": False})
 
         if not (q_network_model_filename is None):
-            rl_planner.agent.load_q_network_model(q_network_model_filename)
+            rl_planner.load_model(q_network_model_filename)
         rl_planner.set_local_map(local_map)
 
         if save_video:
@@ -376,7 +381,7 @@ if __name__ == '__main__':
         rl_planner = MFRLPlanner()
         rl_planner.set_local_map(local_map)
         if not (resume is None):
-            rl_planner.agent.load_q_network_model(resume)
+            rl_planner.agent.load_model(resume)
 
         ################## main loop ########################
         for episode in tqdm.tqdm(range(episodes)):
